@@ -3,9 +3,11 @@ Main interface for codeguru-reviewer service type definitions.
 
 Usage::
 
-    from mypy_boto3.codeguru_reviewer.type_defs import CodeCommitRepositoryTypeDef
+    ```python
+    from mypy_boto3_codeguru_reviewer.type_defs import CodeCommitRepositoryTypeDef
 
     data: CodeCommitRepositoryTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
